"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _validationError = _interopRequireDefault(require("./../validationError"));

/**
 * @name email
 * @description Email validator. This validator checks if the given value is a valid email address.
 * @param {any} value This is the value that will be validated.
 * @throws {ValidationError}
 * @example
 * import { validation } from 'webiny-validation';
 * validation.validate('email@gmail.com', 'email').then(() => {
 *  // Valid
 * }).catch(e => {
 *  // Invalid
 * });
 */
var _default = value => {
  if (!value) return;
  value = value + ""; // eslint-disable-next-line

  const re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;

  if (!value || value.length && re.test(value)) {
    return;
  }

  throw new _validationError.default("Value must be a valid e-mail address.");
};

exports.default = _default;
//# sourceMappingURL=email.js.map